@@ -18,5 +18,5 @@ __all__ = [
     'shell_runner',
     'swift_runner',
     'kotlin_runner',
-    'haskell_runner'
+    # 'haskell_runner'
 ]
